==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/crafting/MarimorphosisRecipe.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.crafting;

import com.google.gson.JsonObject;
import com.google.gson.JsonSyntaxException;
import net.minecraft.class_1865;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_2158;
import net.minecraft.class_2338;
import net.minecraft.class_2378;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3518;
import net.minecraft.class_3956;
import net.minecraft.class_6862;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.api.recipe.StateIngredient;

public class MarimorphosisRecipe extends OrechidRecipe {
	private final int weightBonus;
	private final class_6862<class_1959> biomes;

	public MarimorphosisRecipe(class_2960 id, StateIngredient input, StateIngredient output, int weight,
			class_2158.class_2159 successFunction,
			int weightBonus, class_6862<class_1959> biomes) {
		super(id, input, output, weight, successFunction);
		this.weightBonus = weightBonus;
		this.biomes = biomes;
	}

	@Override
	public int getWeight(@NotNull class_1937 level, @NotNull class_2338 pos) {
		if (level.method_23753(pos).method_40220(this.biomes)) {
			return getWeight() + weightBonus;
		}
		return getWeight();
	}

	@Override
	public class_3956<?> method_17716() {
		return BotaniaRecipeTypes.MARIMORPHOSIS_TYPE;
	}

	@Override
	public class_1865<?> method_8119() {
		return BotaniaRecipeTypes.MARIMORPHOSIS_SERIALIZER;
	}

	public static class Serializer extends RecipeSerializerBase<MarimorphosisRecipe> {
		@Override
		public MarimorphosisRecipe method_8121(@NotNull class_2960 recipeId, @NotNull JsonObject json) {
			OrechidRecipe base = BotaniaRecipeTypes.ORECHID_SERIALIZER.method_8121(recipeId, json);

			var biomes = class_6862.method_40092(class_2378.field_25114,
					new class_2960(class_3518.method_15265(json, "biome_bonus_tag")));
			int weightBonus = class_3518.method_15282(json, "biome_bonus", 0);
			if (base.getWeight() + weightBonus <= 0) {
				throw new JsonSyntaxException("Weight combined with bonus cannot be 0 or less");
			}

			return new MarimorphosisRecipe(recipeId, base.getInput(), base.getOutput(),
					base.getWeight(), base.getSuccessFunction(), weightBonus, biomes);
		}

		@Override
		public MarimorphosisRecipe method_8122(@NotNull class_2960 recipeId, @NotNull class_2540 buffer) {
			OrechidRecipe base = BotaniaRecipeTypes.ORECHID_SERIALIZER.method_8122(recipeId, buffer);

			class_6862<class_1959> biomes = class_6862.method_40092(class_2378.field_25114, buffer.method_10810());
			int weightBonus = buffer.method_10816();

			return new MarimorphosisRecipe(recipeId, base.getInput(), base.getOutput(),
					base.getWeight(), base.getSuccessFunction(), weightBonus, biomes);
		}

		@Override
		public void toNetwork(@NotNull class_2540 buffer, @NotNull MarimorphosisRecipe recipe) {
			BotaniaRecipeTypes.ORECHID_SERIALIZER.method_8124(buffer, recipe);

			buffer.method_10812(recipe.biomes.comp_327());
			buffer.method_10804(recipe.weightBonus);
		}
	}

	public int getWeightBonus() {
		return weightBonus;
	}

	public class_6862<class_1959> getBiomes() {
		return biomes;
	}
}

==> Botania-1.20.1-451-FABRIC-20251110.102138-23-sources.jar: vazkii/botania/common/crafting/MarimorphosisRecipe.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.crafting;

import com.google.gson.JsonObject;
import com.google.gson.JsonSyntaxException;
import net.minecraft.class_1865;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_2158;
import net.minecraft.class_2338;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3518;
import net.minecraft.class_3956;
import net.minecraft.class_6862;
import net.minecraft.class_7924;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.api.recipe.StateIngredient;

public class MarimorphosisRecipe extends OrechidRecipe {
	private final int weightBonus;
	private final class_6862<class_1959> biomes;

	public MarimorphosisRecipe(class_2960 id, StateIngredient input, StateIngredient output, int weight,
			class_2158.class_2159 successFunction,
			int weightBonus, class_6862<class_1959> biomes) {
		super(id, input, output, weight, successFunction);
		this.weightBonus = weightBonus;
		this.biomes = biomes;
	}

	@Override
	public int getWeight(@NotNull class_1937 level, @NotNull class_2338 pos) {
		if (level.method_23753(pos).method_40220(this.biomes)) {
			return getWeight() + weightBonus;
		}
		return getWeight();
	}

	@NotNull
	@Override
	public class_3956<? extends MarimorphosisRecipe> method_17716() {
		return BotaniaRecipeTypes.MARIMORPHOSIS_TYPE;
	}

	@Override
	public class_1865<?> method_8119() {
		return BotaniaRecipeTypes.MARIMORPHOSIS_SERIALIZER;
	}

	public static class Serializer implements class_1865<MarimorphosisRecipe> {
		@Override
		public MarimorphosisRecipe method_8121(@NotNull class_2960 recipeId, @NotNull JsonObject json) {
			OrechidRecipe base = BotaniaRecipeTypes.ORECHID_SERIALIZER.method_8121(recipeId, json);

			var biomes = class_6862.method_40092(class_7924.field_41236,
					new class_2960(class_3518.method_15265(json, "biome_bonus_tag")));
			int weightBonus = class_3518.method_15282(json, "biome_bonus", 0);
			if (base.getWeight() + weightBonus <= 0) {
				throw new JsonSyntaxException("Weight combined with bonus cannot be 0 or less");
			}

			return new MarimorphosisRecipe(recipeId, base.getInput(), base.getOutput(),
					base.getWeight(), base.getSuccessFunction(), weightBonus, biomes);
		}

		@Override
		public MarimorphosisRecipe method_8122(@NotNull class_2960 recipeId, @NotNull class_2540 buffer) {
			OrechidRecipe base = BotaniaRecipeTypes.ORECHID_SERIALIZER.method_8122(recipeId, buffer);

			class_6862<class_1959> biomes = class_6862.method_40092(class_7924.field_41236, buffer.method_10810());
			int weightBonus = buffer.method_10816();

			return new MarimorphosisRecipe(recipeId, base.getInput(), base.getOutput(),
					base.getWeight(), base.getSuccessFunction(), weightBonus, biomes);
		}

		@Override
		public void toNetwork(@NotNull class_2540 buffer, @NotNull MarimorphosisRecipe recipe) {
			BotaniaRecipeTypes.ORECHID_SERIALIZER.method_8124(buffer, recipe);

			buffer.method_10812(recipe.biomes.comp_327());
			buffer.method_10804(recipe.weightBonus);
		}
	}

	public int getWeightBonus() {
		return weightBonus;
	}

	public class_6862<class_1959> getBiomes() {
		return biomes;
	}
}
